% DSGE model of Acurio, Damette, Shanafelt (2020)
% Created by Veronica Acurio Vasconez, July 2020

% This code generates our baseline results and allows the change of economic parameter values
% See "figure_generation_SIR.m" code to generate the paper figures from the resulting data

% The code requires several inputs to run:
% matrix "eco" of the economic parameters of interest (risk premium, leverage, unemployment compensation, CB feedback parameter, and household habit preference)
% code "ADS_main" to structure the Dynare code with initial/final values, given the epidemic parameters
% program Dynare (https://www.dynare.org/)
% function "trajectories_pd" to convert the model output to the percent deviation with respect to the no-disease state

% The code outputs a matrix "Traj", which are the percent deviations of the trajectories from the no-disease state


clc; clear all; close all; % clears plots, plots, and command window

% select the country for the study (U.S or E.U.) - be sure to comment out the other
country = 'US';
%country = 'EU';

% sets economic parameters of interest
% [risk premium (Rk-R), leverage (psi), unemployment compensation (zeta), CB feedback parameter (omega), household habit preferences (h)]

% US baseline (0.01/4 (or 0.0025),4,0.5,10,0.71)
eco=[0.0025 4 0.5 10 0.71];  %leverage < 6.22 and spread < 0.0156 (annual)

% EU baseline (0.07/4,4,0.5,10,0.592)
%eco=[0.01/4 4 0.5 100 0.592];  %leverage < 6.22 and spread < 0.0156 (annual)

save ./Graphs/Results/necessary_eco.mat eco % saves "eco" matrix (will be deleted by later by Dynare)


%%%%%%%%%%%%%%%%
% SIR epidemic %
%%%%%%%%%%%%%%%%

% deletes any result files in subpath to avoid problems
cd ./Graphs/Results
delete results.mat;
delete results_pd_SIR.mat;
delete ss_O.mat;
cd ..
cd ..
   
load ./Graphs/Results/necessary_eco.mat % loads necessary first-order conditions for the model

% sets all other parameters and the no-disease steady-state
cd ./Params_setting
if country == 'US'
    params_set_US(eco); % sets parameters
    cd ./Params_setting
    nodisease_ss_US(eco); % no-disease steady-state
elseif country == 'EU'
    params_set_EU(eco);
    cd ./Params_setting
    nodisease_ss_EU(eco);
else
    msg = 'No country chosen';
    error(msg)
end


% constructing the code and running dynare
run ADS_main; % sets up Dynare simulation
cd dynare;dynare ADS_SIR.mod; % runs Dynare with calibrated settings
cd ..
save ./Graphs/Results/results.mat oo_; % saves simulation results


% calculating percentage deviation of the trajectories with respect to the no-disease steady-state
clear all; % clear all variables

cd ./Graphs/Results
load results.mat; load ss_O.mat; % load simulation and no-disease steady-state trajectories
Traj=trajectories_pd(oo_.endo_simul',oo_.steady_state,vars); % redefines trajectories
save results_pd_SIR.mat Traj; % saves the result

cd ..
cd ..

